@@ -1,5 +1,7 @@
 /*
- *	Copyright (c) 1986-2002, Hiram Clawson - curator@hiram.ws.NoSpam
+ *	$Id: j2d.c,v 1.11 2005/10/06 22:30:13 hiram Exp $
+ *
+ *	Copyright (c) 1986-2005, Hiram Clawson - email: jday at hiram.ws
  *	All rights reserved.
  *
  *	Redistribution and use in source and binary forms, with or
@@ -70,87 +72,111 @@ fprintf(stderr, "j2d - version %s - %s\n", version, date );
 fprintf(stderr, "\t%s\n", jday_copyright );
 }
 
+static void
+shortUsage() {
+fprintf(stderr, "usage: j2d [options] <julian date>\n" );
+fprintf(stderr, "options:\n");
+fprintf(stderr, "\t-v1 = display version 1.3 type of output yyyy/mm/dd\n");
+}
+
 static void
 Usage() {
-fprintf(stderr, "usage: j2d <julian date>\n" );
+shortUsage();
 Version();
 }
 
+int
 main( argc, argv )
 int argc;
 char * argv[];
 {
-	int day;
-	int mo;
-	int hour;
-	int minute;
-	long year;
-	double jd;
-  	time_t now_time;
-	struct tm *local_now;
-	struct ut_instant today;
-	char * cp;
+    int day;
+    int mo;
+    int hour;
+    int minute;
+    int year;
+    double jd;
+    time_t now_time;
+    struct tm *local_now;
+    struct ut_instant today;
+    char * cp;
+    int optV1 = 0;	/*	when == 1 => version 1 type of output */
 
-	time ( & now_time);
-	local_now = localtime  (& now_time);
+    time ( & now_time);
+    local_now = localtime  (& now_time);
 
-	year = local_now->tm_year + 1900;
-	mo = local_now->tm_mon + 1;
-	day = local_now->tm_mday;
-	hour = local_now->tm_hour;
-	minute = local_now->tm_min;
+    year = local_now->tm_year + 1900;
+    mo = local_now->tm_mon + 1;
+    day = local_now->tm_mday;
+    hour = local_now->tm_hour;
+    minute = local_now->tm_min;
 
-	if ( argc > 1 ) {
-		switch ( argc ) {
-			case 2:
-		if ( (char *) NULL != (cp =
-			strstr((const char *)argv[1], (const char *) "-h") ) ){
-				Usage();
-				exit(0);
-				/*	NOTREACHED	*/
-		}
-		if ( (char *) NULL != (cp =
-			strstr((const char *)argv[1], (const char *) "-v") ) ){
-				Version();
-				exit(0);
-				/*	NOTREACHED	*/
-		}
-				jd = atof( argv[1] );
-				break;
-			default:
-				Usage();
-				exit( 0 );
-				/*	NOTREACHED	*/
-				break;
-		}
-	} else {
-		printf( "usage: j2d <julian date>\n" );
-		exit( 0 );
-		/*	NOTREACHED	*/
+    if ( argc > 1 ) {
+	/*check for special arguments, steal them out of the command line*/
+	int i, j;
+	for (i = 0, j = 0; i < argc; ++i) {
+	    if ( ! strcmp((const char *)argv[i], (const char *) "-v1") ) {
+		optV1 = 1;
+	    } else {
+		if (j != i) argv[j] = argv[i];
+		++j;
+	    }
 	}
+	argc = j;
+	switch ( argc ) {
+		case 2:
+	if ( (char *) NULL != (cp =
+		strstr((const char *)argv[1], (const char *) "-h") ) ){
+			Usage();
+			exit(0);
+			/*	NOTREACHED	*/
+	}
+	if ( (char *) NULL != (cp =
+		strstr((const char *)argv[1], (const char *) "-v") ) ){
+			Version();
+			exit(0);
+			/*	NOTREACHED	*/
+	}
+			jd = atof( argv[1] );
+			break;
+		default:
+			Usage();
+			exit( 0 );
+			/*	NOTREACHED	*/
+			break;
+	}
+    } else {
+	    shortUsage();
+	    exit( 0 );
+	    /*	NOTREACHED	*/
+    }
 
 /*	clear the today structure	*/
 
-	today.year = 0;
-	today.month = 0;
-	today.day = 0;
-	today.i_hour = 0;
-	today.i_minute = 0;
-	today.second = 0.0;
-	today.d_hour = 0;
-	today.d_minute = 0;
-	today.weekday = 7;
-	today.day_of_year = 0;
-	today.j_date = 2147483647;
-	today.j_date = (today.j_date * 2.0) + 1.0;
+    today.year = 0;
+    today.month = 0;
+    today.day = 0;
+    today.i_hour = 0;
+    today.i_minute = 0;
+    today.second = 0.0;
+    today.d_hour = 0;
+    today.d_minute = 0;
+    today.weekday = 7;
+    today.day_of_year = 0;
+    today.j_date = 2147483647;
+    today.j_date = (today.j_date * 2.0) + 1.0;
 
-	today.j_date = jd;
-	(void) CalDate( & today );
+    today.j_date = jd;
+    (void) CalDate( & today );
 
-	printf( "%d/%02d/%02d %02d:%02d:%02d\n", today.year,
-		today.month, today.day, today.i_hour, today.i_minute,
-		(int)(today.second + 0.5) );
+    if (optV1)
+	printf( "%d/%02d/%02d", today.year, today.month, today.day);
+    else
+	printf( "%d-%02d-%02d", today.year, today.month, today.day);
 
-	exit( 0 );
-	/*	NOTREACHED	*/
+    printf( " %02d:%02d:%02d\n", today.i_hour, today.i_minute,
+	    (int)(today.second + 0.5) );
+
+    exit( 0 );
+    /*	NOTREACHED	*/
 }
