@@ -1,5 +1,7 @@
 /*
- *	Copyright (c) 1986-2000, Hiram Clawson 
+ *	$Id: version.c,v 1.7 2005/10/06 17:21:35 hiram Exp $
+ *
+ *	Copyright (c) 1986-2005, Hiram Clawson - email: jday at hiram.ws
  *	All rights reserved.
  *
  *	Redistribution and use in source and binary forms, with or
@@ -34,12 +36,11 @@
  *	THE POSSIBILITY OF SUCH DAMAGE. 
  */
 
-char version[] = "1.3";
+char version[] = "2.4";
 char patchlevel[] = "0";
-char date[] = "2002/11/11 11:11:11 UTC - JD 2452589.966100";
-char jday_copyright[] = "Copyright(C) 1999, 2000, 2001, 2002 - curator@hiram.ws";
+char date[] = "2005-10-10 10:10:10 UTC - JD 2453653.923727";
+char jday_copyright[] = "Copyright(C) 1999, 2000, 2001, 2002, 2003, 2004, 2005 - jday at hiram.ws";
 
 char faq_location[] = "http://jday.sourceforge.net/";
-char bug_email[] = "curator@hiram.ws";
+char bug_email[] = "jday at hiram.ws";
 char help_email[] = "http://jday.sourceforge.net/";
-
